Description Usage Arguments Value See Also Examples
fitkm fits a Kaplan-Meier product limit estimator.
1 |
formula |
A formula object with the time variable on the left-hand side. |
delta |
Censoring indicator, 0 = right-censored, 1 = event occurred. |
data |
A data frame containing the variables referred to in |
An object of class fitkm, containing one or more
fitkm.curve objects.
summary.fitkm, plot.fitkm,
fitkm.curve
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.